==> cms-db_v0.8.1.tar.gz: admin/locales/de/locale_files.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['files'] = array();

$locale['files']['link_filelist'] = 'Liste';
$locale['files']['link_newfolder'] = 'Neuer Ordner';

$locale['files']['desc_current-path'] = 'Aktueller Pfad:';

$locale['files']['title_filelist'] = 'Dateiliste';
$locale['files']['desc_folders'] = 'Ordner';
$locale['files']['desc_filename'] = 'Dateiname';
$locale['files']['desc_filesize'] = 'Größe';
$locale['files']['desc_mime'] = 'Dateityp';
$locale['files']['desc_no-files'] = 'Keine Dateien verfügbar!';
$locale['files']['desc_deleted'] = 'Die Datei wurde erfolgreich in das Recycling-Center verschoben.';
$locale['files']['desc_undeleted'] = 'Die Datei wurde erfolgreich wiederhergestellt.';
$locale['files']['desc_recyclebin'] = 'Mit einem Klick auf "löschen" werden Dateien in das Recycling-Center verschoben.';
$locale['files']['title_upload'] = 'Datei hochladen';
$locale['files']['button_upload'] = 'Hochladen';
$locale['files']['desc_error'] = 'Datei konnte nicht hochgeladen werden.';
$locale['files']['desc_error-no-file'] = 'Keine Datei wurde zum Hochladen ausgewählt. Möglicherweise überschreitet die Datei die Maximalgröße von PHP!';
$locale['files']['desc_error-filename'] = 'Eine Datei mit dem gleichen Namen existiert bereits.';
$locale['files']['desc_error-post-size'] = 'Die Datei überschreitet die maximale POST-Größe von PHP.';

$locale['files']['title_editfile'] = 'Datei bearbeiten';

$locale['files']['desc_create-error'] = 'Der Ordner konnte nicht erstellt werden.';

$locale['files']['title_rename'] = 'Datei umbenennen';
$locale['files']['desc_rename'] = 'Datei <i>%s</i> umbenennen in:';
$locale['files']['desc_rename-error'] = 'Die Datei konnte nicht umbenannt werden.';
$locale['files']['desc_rename-error-specialchars'] = 'Der Dateiname enthält Sonderzeichen.';

$locale['files']['title_newfolder'] = 'Ordner erstellen';
$locale['files']['label_folder-name'] = 'Name des Ordners:';
?>

==> cms-db_v0.9.tar.gz: admin/locales/de/locale_files.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['files'] = array();

$locale['files']['desc_current-path'] = 'Aktueller Ordner:';
$locale['files']['desc_folder-root'] = 'Dateien';
$locale['files']['link_uploadfile'] = 'Datei hochladen';
$locale['files']['link_createfolder'] = 'Ordner erstellen';
$locale['files']['desc_no-files'] = 'Keine Dateien verfügbar!';
$locale['files']['desc_deleted'] = 'Die Datei wurde erfolgreich in das Recycling-Center verschoben.';
$locale['files']['desc_undeleted'] = 'Die Datei wurde erfolgreich wiederhergestellt.';
$locale['files']['desc_recyclebin'] = 'Mit einem Klick auf "löschen" werden Dateien in das Recycling-Center verschoben.';
$locale['files']['title_upload'] = 'Datei hochladen';
$locale['files']['desc_uploadfile'] = 'Wählen Sie die Datei, die in den Ordner <em>%s</em> hochgeladen werden soll.';
$locale['files']['button_upload'] = 'Hochladen';
$locale['files']['desc_error'] = 'Datei konnte nicht hochgeladen werden.';
$locale['files']['desc_error-no-file'] = 'Keine Datei wurde zum Hochladen ausgewählt. Möglicherweise überschreitet die Datei die Maximalgröße von PHP!';
$locale['files']['desc_error-filename'] = 'Eine Datei mit dem gleichen Namen existiert bereits.';
$locale['files']['title_newfolder'] = 'Neuen Ordner erstellen';
$locale['files']['desc_folder-name'] = 'Geben Sie einen Namen für den Ordner ein, der in <em>%s</em> erstellt werden soll.';
$locale['files']['title_editfile'] = 'Datei bearbeiten';
$locale['files']['desc_create-error'] = 'Der Ordner konnte nicht erstellt werden.';
$locale['files']['title_rename'] = 'Datei umbenennen';
$locale['files']['desc_rename'] = 'Datei <i>%s</i> umbenennen in:';
$locale['files']['desc_rename-error'] = 'Die Datei konnte nicht umbenannt werden.';
$locale['files']['desc_rename-error-specialchars'] = 'Der Dateiname enthält Sonderzeichen.';
